@@ -11,33 +11,49 @@ use Catalyst qw/
                 Unicode::Encoding
                 Static::Simple
                 StackTrace
+                SubRequest
 /;
 
-our $VERSION = '0.000005';
+our $VERSION = '0.000006';
 $VERSION = eval $VERSION;
 
 __PACKAGE__->config(
     name => 'Gitalist',
     default_view => 'Default',
-    default_model => 'GitRepos',
+    default_model => 'CollectionOfRepos',
 );
 
 __PACKAGE__->setup();
 
+after prepare_path => sub {
+    my ($ctx) = @_;
+    if ($ctx->req->param('a')) {
+        $ctx->request->uri->path('/legacy' . $ctx->request->uri->path);
+    }
+};
+
 around uri_for => sub {
   my ($orig, $c) = (shift, shift);
-  my $repository_name = $c->stash->{'Repository'} && $c->stash->{'Repository'}->name;
-  my $hash = ref($_[-1]) eq 'HASH' ? pop @_ : {};
-  my $params = Catalyst::Utils::merge_hashes(
-    { p => $hash->{p} || $repository_name },
-    $hash,
-  );
-  delete $params->{p} unless defined $params->{p} && length $params->{p};
-  (my $uri = $c->$orig(@_, $params))
-    =~ tr[&][;];
+  my $uri = $c->$orig(@_);
+  $$uri =~ tr[&][;] if defined $uri;
   return $uri;
 };
 
+around uri_for_action => sub {
+  my ($orig, $c) = (shift, shift);
+  my $uri = $c->$orig(@_);
+  $$uri =~ s[/fragment\b][] if defined $uri;
+  return $uri;
+};
+
+sub uri_with {
+  my ($self, @args) = @_;
+  my $uri = $self->request->uri_with(@args);
+  # Wow this awful.
+  $uri =~ s[/fragment\b][];
+  return $uri;  
+}
+
 1;
 
 __END__
@@ -90,7 +106,7 @@ Alternatively, you can get Gitalist using git.
 
 The canonical repository for the master branch is:
 
-    it://git.shadowcat.co.uk/catagits/Gitalist.git
+    git://git.shadowcat.co.uk/catagits/Gitalist.git
 
 Gitalist is also mirrored to github, and a number of people have active forks
 with branches and/or new features in the master branch.
@@ -130,13 +146,13 @@ You can then start the Gitalist demo server by setting C<< GITALIST_CONFIG >>. F
     GITALIST_CONFIG=/usr/local/etc/gitalist.conf gitalist_server.pl
 
 Alternatively, if you only want to set a repository directory and are otherwise happy with
-the default configuration, then you can set the C<< GITALIST_REPOS_DIR >> environment
+the default configuration, then you can set the C<< GITALIST_REPO_DIR >> environment
 variable, or pass the C<< --repos_dir >> flag to any of the scripts.
 
-    GITALIST_REPOS_DIR=/home/myuser/code/git gitalist_server.pl
+    GITALIST_REPO_DIR=/home/myuser/code/git gitalist_server.pl
     gitalist_server.pl --repos_dir home/myuser/code/git
 
-The C<< GITALIST_REPOS_DIR >> environment variable will override the repository directory set
+The C<< GITALIST_REPO_DIR >> environment variable will override the repository directory set
 in configuration, and will itself be overridden by he C<< --repos_dir >> flag.
 
 =head1 RUNNING
